@@ -3,7 +3,7 @@
 
 __version__ = (0, 0, 0)
 __author__ = "ChenyangGao <https://github.com/ChenyangGao>"
-__all__ = ["Error", "Client", "ShareList"]
+__all__ = ["Error", "DuPanClient", "DuPanShareList"]
 
 import errno
 
@@ -74,7 +74,7 @@ class VCodeResult(TypedDict, total=True):
 
 def recognize_vcode(_ocr=DdddOcr(beta=True), /) -> VCodeResult:
     "识别百度网盘的验证码"
-    url = "https://pan.baidu.com/api/getcaptcha?prod=shareverify&web=1&clienttype=0&bdstoken="
+    url = "https://pan.baidu.com/api/getcaptcha?prod=shareverify&web=1&DuPanClienttype=0&bdstoken="
     while True:
         resp = get(url).json()
         for i in range(10):
@@ -171,7 +171,7 @@ class Error(OSError):
         return resp
 
 
-class Client:
+class DuPanClient:
 
     def __init__(self, cookie: Optional[str] = None):
         session = self.session = Session()
@@ -275,7 +275,7 @@ class Client:
 
     @staticmethod
     def list_app_version():
-        url = "https://pan.baidu.com/disk/cmsdata?clienttype=0&web=1&do=client"
+        url = "https://pan.baidu.com/disk/cmsdata?DuPanClienttype=0&web=1&do=DuPanClient"
         return get(url).json()
 
     def get_qrcode(self, /, gid):
@@ -326,14 +326,14 @@ class Client:
             page: int = 1
             order: str = "time"
             desc: 0 | 1 = 1
-            clienttype: int = 0
+            DuPanClienttype: int = 0
             web: int = 1
         """
         api = "https://pan.baidu.com/api/list"
         if isinstance(payload, str):
-            payload = {"num": 100, "page": 1, "order": "time", "desc": 1, "clienttype": 0, "web": 1, "dir": payload}
+            payload = {"num": 100, "page": 1, "order": "time", "desc": 1, "DuPanClienttype": 0, "web": 1, "dir": payload}
         else:
-            payload = {"num": 100, "page": 1, "order": "time", "desc": 1, "clienttype": 0, "web": 1, **payload}
+            payload = {"num": 100, "page": 1, "order": "time", "desc": 1, "DuPanClienttype": 0, "web": 1, **payload}
         return self.request(api, params=payload)
 
     def makedir(
@@ -345,7 +345,7 @@ class Client:
         params = {
             "a": "commit", 
             "bdstoken": self.bdstoken, 
-            "clienttype": 0, 
+            "DuPanClienttype": 0, 
             "web": 1, 
         }
         if isinstance(payload, str):
@@ -368,7 +368,7 @@ class Client:
             "onnest": "fail", 
             "bdstoken": self.bdstoken, 
             "newVerify": 1, 
-            "clienttype": 0, 
+            "DuPanClienttype": 0, 
             "web": 1, 
             **params, 
         }
@@ -416,7 +416,7 @@ class Client:
     ) -> dict:
         api = "https://pan.baidu.com/share/taskquery"
         if isinstance(payload, (int, str)):
-            payload = {"clienttype": 0, "web": 1, "taskid": payload}
+            payload = {"DuPanClienttype": 0, "web": 1, "taskid": payload}
         return self.request(api, params=payload)
 
     def transfer(
@@ -432,7 +432,7 @@ class Client:
             "async": 1, 
             "bdstoken": self.bdstoken, 
             "web": 1, 
-            "clienttype": 0, 
+            "DuPanClienttype": 0, 
             **params, 
         }
         if isinstance(data, (int, str)):
@@ -444,7 +444,7 @@ class Client:
         return self.request(api, "POST", params=params, data=data, headers={"Referer": url})
 
 
-class ShareList:
+class DuPanShareList:
 
     def __init__(self, url):
         if url.startswith(("http://", "https://")):
@@ -500,7 +500,7 @@ class ShareList:
 
     def verify(self, /) -> str:
         api = "https://pan.baidu.com/share/verify"
-        params: dict[str, int | str] = {"surl": self.shorturl, "web": 1, "clienttype": 0}
+        params: dict[str, int | str] = {"surl": self.shorturl, "web": 1, "DuPanClienttype": 0}
         data = {"pwd": self.password}
         session = self.session
         while True:
@@ -561,7 +561,7 @@ class ShareList:
             "order": "other", 
             "desc": 1, 
             "showempty": 0, 
-            "clienttype": 0, 
+            "DuPanClienttype": 0, 
             "web": 1, 
             "page": 1, 
             "num": 100, 
